.. |travis| image:: https://travis-ci.com/gjeusel/ticts.svg?branch=master
  :target: https://travis-ci.com/gjeusel/ticts
.. |readthedocs| image:: https://readthedocs.org/projects/ticts/badge/?version=latest
  :target: http://ticts.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status
.. |codecov| image:: https://codecov.io/gh/gjeusel/ticts/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/gjeusel/ticts
.. |pypi| image:: https://badge.fury.io/py/ticts.svg
  :target: https://pypi.python.org/pypi/ticts/
  :alt: Pypi package
.. |license| image:: https://img.shields.io/github/license/gjeusel/ticts.svg
.. |python| image:: https://img.shields.io/badge/python-3.6%2B-blue.svg
  :target: https://www.python.org/downloads/release/python-360/
  :alt: Python version 3.6+


===============================
ticts
===============================
|travis| |codecov| |readthedocs| |license| |python| |pypi|


A Python library for unevenly-spaced time series analysis


Installation
------------

.. code:: bash

    pip install ticts


:License: MIT license
:Documentation: http://ticts.readthedocs.io/en/latest
:Source: https://github.com/gjeusel/ticts
